#target illustrator  

/*———————————————————————————————————————— Gaussian Blend.jsx

    Adobe Illustrator Script
    
    Copy into Applications/Adobe Illustrator 202x/Presets-Scripts/.../Scripts
    
    Takes an expanded blend (Group) where the transparency distribution is
    linear decreasing, and makes the distribution gaussian.

    The result is a more natural blend that imitates a gaussian blur. */

/*———————————————————————————————————————— EULA

    Copyright (c) 2021 Svija

    Permission is hereby granted, free of charge, to any person obtaining a copy
    of this software and associated documentation files (the "Software"), to deal
    in the Software without restriction, including without limitation the rights
    to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is
    furnished to do so, subject to the following conditions:
    
    The above copyright notice and this permission notice shall be included in
    all copies or substantial portions of the Software.
    
    The software is provided "as is", without warranty of any kind, express or
    implied, including but not limited to the warranties of merchantability,
    fitness for a particular purpose and noninfringement. In no event shall the
    authors or copyright holders be liable for any claim, damages or other
    liability, whether in an action of contract, tort or otherwise, arising from,
    out of or in connection with the software or the use or other dealings in
    the software.

  	svija.love · contact@svija.love */

/*———————————————————————————————————————— initialize

    set any path with opacity 0 to opacity 0.5
    there's no reason to have an empty path — it's not visible */

var minVisible = 0.5;


/*  range of arctangent function to use; 5 = arctan(-2.5) to arctan(2.5)
    higher numbers have much steeper transition */

var atan_range = 5;

//———————————————————————————————————————— validate selection

var instr = '\nSelection must be an expanded blend ("group" object with at least 5 steps)';

program:{

  if (app.selection.length > 1)                { alert('Too Many Objects Selected' + instr); break program; }
  if (app.selection.length < 1)                { alert('No selection' + instr); break program; }
  if (app.selection[0].typename != 'GroupItem'){ alert('Please Select a Group' + instr); break program; }

//———————————————————————————————————————— info for existing blend

  var shapes = app.selection[0].pageItems; // front to back, opaque to transp.
  var steps = shapes.length;

  if (steps < 5){ alert('Not enough steps' + instr); break program; }

  var maxOpacity = shapes[0].opacity;
  var minOpacity = shapes[steps - 1].opacity;

  if (minOpacity < minVisible) minOpacity = minVisible;

  var dif = maxOpacity - minOpacity;
  if (Math.abs(dif) < 10){ alert('Not an expanded blend' + instr); break program; }

//———————————————————————————————————————— starting input value & increment

  var inVal = 0 - atan_range / 2;
  var increment = atan_range / (steps-1);

//———————————————————————————————————————— update objects

  for (x=0; x<steps; x++){

    var outVal;
    outVal = Math.atan(inVal);

    outVal = outVal * Math.PI / Math.atan(atan_range / 2); // fill range -pi ... pi
    outVal = 50 - outVal * dif / (Math.PI * 2);            // convert to 100 ... 0
    outVal = outVal - (100 - maxOpacity - minOpacity)/2;   // match min/max opacities

    shapes[x].opacity = outVal;
    inVal += increment;
  }
}


//———————————————————————————————————————— fin
